==> haskell-hls-cabal-plugin-2.1.0.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-plugin-2.1.0.0-jyl5FSWJdc4YvNfSb6Xvf
key:                  hls-cabal-plugin-2.1.0.0-jyl5FSWJdc4YvNfSb6Xvf
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1ca3df51a290c61320c207b5e3ea26d0
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.1.0.0-jyl5FSWJdc4YvNfSb6Xvf
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0 directory-1.3.7.1
    extra-1.7.16-LQUfvtEfMy7348UPPFk3zp filepath-1.4.2.2
    ghcide-2.1.0.0-EYMTVOyZMMaC6uF1m4eXhb
    hashable-1.4.4.0-32D8TF68xTpFTCUtV1slOl
    hls-graph-2.1.0.0-CIT2AImOP8m12ug7Dw0wAV
    hls-plugin-api-2.1.0.0-e6GrNFwzFvKJpzjvkMU36
    lens-5.3.1-Hr3CNVd7aJGEq0oCRlwS0q
    lsp-2.1.0.0-ESPZwykhtv3A4GR6I6px0n
    lsp-types-2.0.1.0-KiCspaCQ8rRKrhhZlz0Jvf
    regex-tdfa-1.3.2.4-BJKBegr0FQF632uWHjLMg4 stm-2.5.1.0 text-2.0.2
    text-rope-0.3-BIjb3KAnUj9GcomM3mKBDb transformers-0.5.6.2
    unordered-containers-0.2.20-AhSAKQoMQ97FOa03PWrXZ

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-plugin-2.1.0.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-plugin-2.1.0.0-JqRx5CzGoa2LJt7eYr1WDi
key:                  hls-cabal-plugin-2.1.0.0-JqRx5CzGoa2LJt7eYr1WDi
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  56a18437eb854a56575bae6e4bab56f3
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.1.0.0-JqRx5CzGoa2LJt7eYr1WDi
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0 directory-1.3.7.1
    extra-1.7.16-2NFI8foRfl5F586yJkh1o1 filepath-1.4.2.2
    ghcide-2.1.0.0-IfdVyiF6AwPDHn2TbAPnXk
    hashable-1.4.4.0-Htybuq5UDQvAvffgJDQoKe
    hls-graph-2.1.0.0-CKpYjZtV40aGyPfbCsIcyO
    hls-plugin-api-2.1.0.0-2tKKyoZfjr7D6pGZz9pYOL
    lens-5.3.1-DW98VpYgL8e3Qofq450fQJ
    lsp-2.1.0.0-6qUz56YkN9c2lHkJ0EY2b5
    lsp-types-2.0.1.0-7wJsN0VEEwO80han8zwlCy
    regex-tdfa-1.3.2.4-2tggK3dv6qG2BQKi0Zlyyt stm-2.5.1.0 text-2.0.2
    text-rope-0.3-AwLiv4qcYXJLMBvcbC2Z73 transformers-0.5.6.2
    unordered-containers-0.2.20-FOY8P5Y3sqjANbVUEJi9Vi

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
